@@ -3,8 +3,6 @@ use strict;
 use base qw(Exporter);
 our @EXPORT = qw(run cli);
 
-use Test::Requires qw( Capture::Tiny File::pushd );
-
 sub cli {
     my $cli = TestCLI->new(clean => $ENV{TEST_CLEAN}, @_);
     $cli->dir( Path::Tiny->tempdir(CLEANUP => !$ENV{NO_CLEANUP}) );
@@ -37,6 +35,13 @@ sub write_cpanfile {
     $self->write_file(cpanfile => @args);
 }
 
+sub path {
+    my($self, @args) = @_;
+    my $path = $self->dir->child(@args);
+    $path->parent->mkpath unless $path->parent->exists;
+    $path;
+}
+
 sub run_in_dir {
     my($self, $dir, @args) = @_;
     local $self->{dir} = $self->dir->child($dir);
